#ifndef INKOMPATIBEL_H
#define INKOMPATIBEL_H

//#ifdef HAVE_FREEQT
//#include <kstddirs.h>
//#endif

/* Sollte immer das erste sein, was included wird (falls irgendwelche
   bools oder so definiert werden). */
#include <config.h>

/* Da steht die QT-Version drin: */
#include <qglobal.h>



#if QT_VERSION < 200
#define QT_V1 1
#else
#define QT_V1 0
#endif


#if QT_V1
#define __ColorOnly ColorOnly
#define __lightGray lightGray
#define __darkGray darkGray
#define __white white
#define __black black
#define __String QString
/* gibt an, ob QMap oder die stl-map verwendet wird. */
#ifndef map_stl
#define map_stl 1
#endif

#else // QT 2
#define __ColorOnly Qt::ColorOnly
#define __lightGray Qt::lightGray
#define __darkGray Qt::darkGray
#define __white Qt::white
#define __black Qt::black
#define __String QCString
#ifndef map_stl
#define map_stl 0
#endif
#endif




#ifndef HAVE_LIBZ
#define HAVE_LIBZ 0
#endif


#ifdef WIN32
/* Ob das folgende die beste Lsung fr Windows ist, wei ich nicht.
   Aber es ist eine. */s
#ifndef PKGDATADIR
#define PKGDATADIR (PACKAGE"-"VERSION"\\data")
#endif

/* Windows: Default hat kein getopt */
#ifndef HAVE_GETOPT
#define HAVE_GETOPT 0
#endif

#else
/* Nicht Windows: Default hat getopt */
#ifndef HAVE_GETOPT
#define HAVE_GETOPT 1
#endif

#endif



#endif

